==> ejc-zjkjcost-api-3.0.0-20230419.031408-137-sources.jar: com/ejianc/business/zjkjcost/finish/vo/RefundVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;


/**
 * 竣工考核-对象预留奖金返还审批-主表
 *
 * @author generator
 *
 */
@ApiModel("竣工考核-对象预留奖金返还审批-主表")
public class RefundVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("合同主键")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同code")
    private String contractCode;
    @ApiModelProperty("项目")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目code")
    private String projectCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("组织code")
    private String orgCode;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("父级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("项目部支付清收费")
    private BigDecimal departmentPayMny;
    @ApiModelProperty("项目部申请返还预留金")
    private BigDecimal departmentApplyMny;
    @ApiModelProperty("所属单位商务管理部兑现预留金")
    private BigDecimal businessRemainMny;
    @ApiModelProperty("所属单位商务管理部扣除实际支付清收费")
    private BigDecimal businessActualPayMny;
    @ApiModelProperty("所属单位商务管理部应返还预留金")
    private BigDecimal businessBackMny;
    @ApiModelProperty("所属单位商务管理部实际返还预留金")
    private BigDecimal businessActualMny;
    @ApiModelProperty("所属单位财务资金部实际支付清收费")
    private BigDecimal capitalActualMny;
    @ApiModelProperty("所属单位财务资金部建议返还预留金")
    private BigDecimal capitalBackMny;
    @ApiModelProperty(" 所属单位分管领导实际支付清收费")
    private BigDecimal leaderPayMny;
    @ApiModelProperty(" 所属单位分管领导实际返还预留金")
    private BigDecimal leaderBackMny;
    @ApiModelProperty("所属单位总经理实际返还预留金")
    private BigDecimal leaderActualMny;
    @ApiModelProperty("所属单位董事长实际返还预留金")
    private BigDecimal chairmanActualMny;
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billStateName;
    private Integer refundFlag;
    private Integer refundFlag1;

    @ApiModelProperty("根据相关管理办法项目目标责任书，审计报告计算奖金额度")
    private String calculate; // 根据相关管理办法项目目标责任书，审计报告计算奖金额度
    @ApiModelProperty("发放总金额")
    private BigDecimal totalAmount; // 发放总金额
    @ApiModelProperty("实发金额——节点考核发放")
    private BigDecimal actualMnyGrant; // 实发金额——节点考核发放
    @ApiModelProperty("实发金额——竣工考核发放")
    private BigDecimal actualMnyOut; // 实发金额——竣工考核发放
    @ApiModelProperty("审批意见——所属单位财务资金部")
    private String capitalOpinion; // 审批意见——所属单位财务资金部
    @ApiModelProperty("审批意见——所属单位分管领导")
    private String leaderOpinion; // 审批意见——所属单位分管领导
    @ApiModelProperty("审批意见——所属单位总经理")
    private String leaderActualOpinion; // 审批意见——所属单位总经理
    @ApiModelProperty("审批意见——所属单位董事长")
    private String chairmanOpinion; // 审批意见——所属单位董事长

    public Integer getRefundFlag1() {
        return refundFlag1;
    }

    public void setRefundFlag1(Integer refundFlag1) {
        this.refundFlag1 = refundFlag1;
    }

    public String getCalculate() {
        return calculate;
    }

    public void setCalculate(String calculate) {
        this.calculate = calculate;
    }

    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    public BigDecimal getActualMnyGrant() {
        return actualMnyGrant;
    }

    public void setActualMnyGrant(BigDecimal actualMnyGrant) {
        this.actualMnyGrant = actualMnyGrant;
    }

    public BigDecimal getActualMnyOut() {
        return actualMnyOut;
    }

    public void setActualMnyOut(BigDecimal actualMnyOut) {
        this.actualMnyOut = actualMnyOut;
    }

    public String getCapitalOpinion() {
        return capitalOpinion;
    }

    public void setCapitalOpinion(String capitalOpinion) {
        this.capitalOpinion = capitalOpinion;
    }

    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }

    public String getLeaderActualOpinion() {
        return leaderActualOpinion;
    }

    public void setLeaderActualOpinion(String leaderActualOpinion) {
        this.leaderActualOpinion = leaderActualOpinion;
    }

    public String getChairmanOpinion() {
        return chairmanOpinion;
    }

    public void setChairmanOpinion(String chairmanOpinion) {
        this.chairmanOpinion = chairmanOpinion;
    }

    public Integer getRefundFlag() {
        return refundFlag;
    }

    public void setRefundFlag(Integer refundFlag) {
        this.refundFlag = refundFlag;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同code
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同code
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目code
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目code
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织code
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 组织code
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 父级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 父级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 项目部支付清收费
     */
    public BigDecimal getDepartmentPayMny() {
        return departmentPayMny;
    }

    /**
     * 项目部支付清收费
     */
    public void setDepartmentPayMny(BigDecimal departmentPayMny) {
        this.departmentPayMny = departmentPayMny;
    }
    /**
     * 项目部申请返还预留金
     */
    public BigDecimal getDepartmentApplyMny() {
        return departmentApplyMny;
    }

    /**
     * 项目部申请返还预留金
     */
    public void setDepartmentApplyMny(BigDecimal departmentApplyMny) {
        this.departmentApplyMny = departmentApplyMny;
    }
    /**
     * 所属单位商务管理部兑现预留金
     */
    public BigDecimal getBusinessRemainMny() {
        return businessRemainMny;
    }

    /**
     * 所属单位商务管理部兑现预留金
     */
    public void setBusinessRemainMny(BigDecimal businessRemainMny) {
        this.businessRemainMny = businessRemainMny;
    }
    /**
     * 所属单位商务管理部扣除实际支付清收费
     */
    public BigDecimal getBusinessActualPayMny() {
        return businessActualPayMny;
    }

    /**
     * 所属单位商务管理部扣除实际支付清收费
     */
    public void setBusinessActualPayMny(BigDecimal businessActualPayMny) {
        this.businessActualPayMny = businessActualPayMny;
    }
    /**
     * 所属单位商务管理部应返还预留金
     */
    public BigDecimal getBusinessBackMny() {
        return businessBackMny;
    }

    /**
     * 所属单位商务管理部应返还预留金
     */
    public void setBusinessBackMny(BigDecimal businessBackMny) {
        this.businessBackMny = businessBackMny;
    }
    /**
     * 所属单位商务管理部实际返还预留金
     */
    public BigDecimal getBusinessActualMny() {
        return businessActualMny;
    }

    /**
     * 所属单位商务管理部实际返还预留金
     */
    public void setBusinessActualMny(BigDecimal businessActualMny) {
        this.businessActualMny = businessActualMny;
    }
    /**
     * 所属单位财务资金部实际支付清收费
     */
    public BigDecimal getCapitalActualMny() {
        return capitalActualMny;
    }

    /**
     * 所属单位财务资金部实际支付清收费
     */
    public void setCapitalActualMny(BigDecimal capitalActualMny) {
        this.capitalActualMny = capitalActualMny;
    }
    /**
     * 所属单位财务资金部建议返还预留金
     */
    public BigDecimal getCapitalBackMny() {
        return capitalBackMny;
    }

    /**
     * 所属单位财务资金部建议返还预留金
     */
    public void setCapitalBackMny(BigDecimal capitalBackMny) {
        this.capitalBackMny = capitalBackMny;
    }
    /**
     *  所属单位分管领导实际支付清收费
     */
    public BigDecimal getLeaderPayMny() {
        return leaderPayMny;
    }

    /**
     *  所属单位分管领导实际支付清收费
     */
    public void setLeaderPayMny(BigDecimal leaderPayMny) {
        this.leaderPayMny = leaderPayMny;
    }
    /**
     *  所属单位分管领导实际返还预留金
     */
    public BigDecimal getLeaderBackMny() {
        return leaderBackMny;
    }

    /**
     *  所属单位分管领导实际返还预留金
     */
    public void setLeaderBackMny(BigDecimal leaderBackMny) {
        this.leaderBackMny = leaderBackMny;
    }
    /**
     * 所属单位总经理实际返还预留金
     */
    public BigDecimal getLeaderActualMny() {
        return leaderActualMny;
    }

    /**
     * 所属单位总经理实际返还预留金
     */
    public void setLeaderActualMny(BigDecimal leaderActualMny) {
        this.leaderActualMny = leaderActualMny;
    }
    /**
     * 所属单位董事长实际返还预留金
     */
    public BigDecimal getChairmanActualMny() {
        return chairmanActualMny;
    }

    /**
     * 所属单位董事长实际返还预留金
     */
    public void setChairmanActualMny(BigDecimal chairmanActualMny) {
        this.chairmanActualMny = chairmanActualMny;
    }
    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}

==> ejc-zjkjcost-api-3.0.0-20230510.105124-162-sources.jar: com/ejianc/business/zjkjcost/finish/vo/RefundVO.java <==
package com.ejianc.business.zjkjcost.finish.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;


/**
 * 竣工考核-对象预留奖金返还审批-主表
 *
 * @author generator
 *
 */
@ApiModel("竣工考核-对象预留奖金返还审批-主表")
public class RefundVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("合同主键")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同code")
    private String contractCode;
    @ApiModelProperty("项目")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目code")
    private String projectCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("组织code")
    private String orgCode;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("父级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("项目部支付清收费")
    private BigDecimal departmentPayMny;
    @ApiModelProperty("项目部申请返还预留金")
    private BigDecimal departmentApplyMny;
    @ApiModelProperty("所属单位商务管理部兑现预留金")
    private BigDecimal businessRemainMny;
    @ApiModelProperty("所属单位商务管理部扣除实际支付清收费")
    private BigDecimal businessActualPayMny;
    @ApiModelProperty("所属单位商务管理部应返还预留金")
    private BigDecimal businessBackMny;
    @ApiModelProperty("所属单位商务管理部实际返还预留金")
    private BigDecimal businessActualMny;
    @ApiModelProperty("所属单位财务资金部实际支付清收费")
    private BigDecimal capitalActualMny;
    @ApiModelProperty("所属单位财务资金部建议返还预留金")
    private BigDecimal capitalBackMny;
    @ApiModelProperty(" 所属单位分管领导实际支付清收费")
    private BigDecimal leaderPayMny;
    @ApiModelProperty(" 所属单位分管领导实际返还预留金")
    private BigDecimal leaderBackMny;
    @ApiModelProperty("所属单位总经理实际返还预留金")
    private BigDecimal leaderActualMny;
    @ApiModelProperty("所属单位董事长实际返还预留金")
    private BigDecimal chairmanActualMny;
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @ApiModelProperty("单据状态（审批必须字段）")
    private String billStateName;
    private Integer refundFlag;
    private Integer refundFlag1;

    @ApiModelProperty("根据相关管理办法项目目标责任书，审计报告计算奖金额度")
    private String calculate; // 根据相关管理办法项目目标责任书，审计报告计算奖金额度
    @ApiModelProperty("发放总金额")
    private BigDecimal totalAmount; // 发放总金额
    @ApiModelProperty("实发金额——节点考核发放")
    private BigDecimal actualMnyGrant; // 实发金额——节点考核发放
    @ApiModelProperty("实发金额——竣工考核发放")
    private BigDecimal actualMnyOut; // 实发金额——竣工考核发放
    @ApiModelProperty("审批意见——所属单位财务资金部")
    private String capitalOpinion; // 审批意见——所属单位财务资金部
    @ApiModelProperty("审批意见——所属单位分管领导")
    private String leaderOpinion; // 审批意见——所属单位分管领导
    @ApiModelProperty("审批意见——所属单位总经理")
    private String leaderActualOpinion; // 审批意见——所属单位总经理
    @ApiModelProperty("审批意见——所属单位董事长")
    private String chairmanOpinion; // 审批意见——所属单位董事长

    private BigDecimal applyReturnMny; // 申请返还金额

    public Integer getRefundFlag1() {
        return refundFlag1;
    }

    public void setRefundFlag1(Integer refundFlag1) {
        this.refundFlag1 = refundFlag1;
    }

    public String getCalculate() {
        return calculate;
    }

    public void setCalculate(String calculate) {
        this.calculate = calculate;
    }

    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    public BigDecimal getActualMnyGrant() {
        return actualMnyGrant;
    }

    public void setActualMnyGrant(BigDecimal actualMnyGrant) {
        this.actualMnyGrant = actualMnyGrant;
    }

    public BigDecimal getActualMnyOut() {
        return actualMnyOut;
    }

    public void setActualMnyOut(BigDecimal actualMnyOut) {
        this.actualMnyOut = actualMnyOut;
    }

    public String getCapitalOpinion() {
        return capitalOpinion;
    }

    public void setCapitalOpinion(String capitalOpinion) {
        this.capitalOpinion = capitalOpinion;
    }

    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }

    public String getLeaderActualOpinion() {
        return leaderActualOpinion;
    }

    public void setLeaderActualOpinion(String leaderActualOpinion) {
        this.leaderActualOpinion = leaderActualOpinion;
    }

    public String getChairmanOpinion() {
        return chairmanOpinion;
    }

    public void setChairmanOpinion(String chairmanOpinion) {
        this.chairmanOpinion = chairmanOpinion;
    }

    public Integer getRefundFlag() {
        return refundFlag;
    }

    public void setRefundFlag(Integer refundFlag) {
        this.refundFlag = refundFlag;
    }
    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同code
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同code
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目code
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目code
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 组织code
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 组织code
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 父级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 父级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 项目部支付清收费
     */
    public BigDecimal getDepartmentPayMny() {
        return departmentPayMny;
    }

    /**
     * 项目部支付清收费
     */
    public void setDepartmentPayMny(BigDecimal departmentPayMny) {
        this.departmentPayMny = departmentPayMny;
    }
    /**
     * 项目部申请返还预留金
     */
    public BigDecimal getDepartmentApplyMny() {
        return departmentApplyMny;
    }

    /**
     * 项目部申请返还预留金
     */
    public void setDepartmentApplyMny(BigDecimal departmentApplyMny) {
        this.departmentApplyMny = departmentApplyMny;
    }
    /**
     * 所属单位商务管理部兑现预留金
     */
    public BigDecimal getBusinessRemainMny() {
        return businessRemainMny;
    }

    /**
     * 所属单位商务管理部兑现预留金
     */
    public void setBusinessRemainMny(BigDecimal businessRemainMny) {
        this.businessRemainMny = businessRemainMny;
    }
    /**
     * 所属单位商务管理部扣除实际支付清收费
     */
    public BigDecimal getBusinessActualPayMny() {
        return businessActualPayMny;
    }

    /**
     * 所属单位商务管理部扣除实际支付清收费
     */
    public void setBusinessActualPayMny(BigDecimal businessActualPayMny) {
        this.businessActualPayMny = businessActualPayMny;
    }
    /**
     * 所属单位商务管理部应返还预留金
     */
    public BigDecimal getBusinessBackMny() {
        return businessBackMny;
    }

    /**
     * 所属单位商务管理部应返还预留金
     */
    public void setBusinessBackMny(BigDecimal businessBackMny) {
        this.businessBackMny = businessBackMny;
    }
    /**
     * 所属单位商务管理部实际返还预留金
     */
    public BigDecimal getBusinessActualMny() {
        return businessActualMny;
    }

    /**
     * 所属单位商务管理部实际返还预留金
     */
    public void setBusinessActualMny(BigDecimal businessActualMny) {
        this.businessActualMny = businessActualMny;
    }
    /**
     * 所属单位财务资金部实际支付清收费
     */
    public BigDecimal getCapitalActualMny() {
        return capitalActualMny;
    }

    /**
     * 所属单位财务资金部实际支付清收费
     */
    public void setCapitalActualMny(BigDecimal capitalActualMny) {
        this.capitalActualMny = capitalActualMny;
    }
    /**
     * 所属单位财务资金部建议返还预留金
     */
    public BigDecimal getCapitalBackMny() {
        return capitalBackMny;
    }

    /**
     * 所属单位财务资金部建议返还预留金
     */
    public void setCapitalBackMny(BigDecimal capitalBackMny) {
        this.capitalBackMny = capitalBackMny;
    }
    /**
     *  所属单位分管领导实际支付清收费
     */
    public BigDecimal getLeaderPayMny() {
        return leaderPayMny;
    }

    /**
     *  所属单位分管领导实际支付清收费
     */
    public void setLeaderPayMny(BigDecimal leaderPayMny) {
        this.leaderPayMny = leaderPayMny;
    }
    /**
     *  所属单位分管领导实际返还预留金
     */
    public BigDecimal getLeaderBackMny() {
        return leaderBackMny;
    }

    /**
     *  所属单位分管领导实际返还预留金
     */
    public void setLeaderBackMny(BigDecimal leaderBackMny) {
        this.leaderBackMny = leaderBackMny;
    }
    /**
     * 所属单位总经理实际返还预留金
     */
    public BigDecimal getLeaderActualMny() {
        return leaderActualMny;
    }

    /**
     * 所属单位总经理实际返还预留金
     */
    public void setLeaderActualMny(BigDecimal leaderActualMny) {
        this.leaderActualMny = leaderActualMny;
    }
    /**
     * 所属单位董事长实际返还预留金
     */
    public BigDecimal getChairmanActualMny() {
        return chairmanActualMny;
    }

    /**
     * 所属单位董事长实际返还预留金
     */
    public void setChairmanActualMny(BigDecimal chairmanActualMny) {
        this.chairmanActualMny = chairmanActualMny;
    }
    /**
     * 合同主键
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public BigDecimal getApplyReturnMny() {
        return applyReturnMny;
    }

    public void setApplyReturnMny(BigDecimal applyReturnMny) {
        this.applyReturnMny = applyReturnMny;
    }
}
